@@ -142,14 +142,15 @@ disable_plugins = []  # type: List[str]
 custom_user_code = ""
 custom_tenant_code = ""
 custom_env_code = ""
+custom_service_version = ""
 
 
 def init(
         service: str = None, instance: str = None, collector: str = None, protocol_type: str = "udp", token: str = None
 ):
     # 先根据环境变量 FastTracker_ConfigPath 加载配置文件并赋值
-    config_file = os.environ.get("FastTracker_ConfigPath", None)
-    print("FastTracker_ConfigPath is %s " % config_file)
+    config_file = os.environ.get("FastTracker.ConfigPath", None)
+    print("FastTracker.ConfigPath is %s " % config_file)
     from fast_tracker.fast_tracker_configer import FastTrackerConfiger
 
     if config_file:
@@ -184,24 +185,24 @@ def set_enable(cus_enable: bool = False):
     enable = cus_enable
 
 
-# def set_debug(cus_debug: bool = False):
-#     """
-#     设置 debug 值
-#     :param cus_debug:
-#     :return:
-#     """
-#     global debug
-#     debug = cus_debug
+def set_debug(cus_debug: bool = False):
+    """
+    设置 debug 值
+    :param cus_debug:
+    :return:
+    """
+    global debug
+    debug = cus_debug
 
 
-# def set_debug_level(cus_debug_level: int = 0):
-#     """
-#     设置 debug_level 值
-#     :param cus_debug_level:
-#     :return:
-#     """
-#     global debug_level
-#     debug_level = cus_debug_level
+def set_debug_level(cus_debug_level: int = 0):
+    """
+    设置 debug_level 值
+    :param cus_debug_level:
+    :return:
+    """
+    global debug_level
+    debug_level = cus_debug_level
 
 
 # def set_env_code(cus_env_code: str = ""):
@@ -272,7 +273,8 @@ def set_service_version(cus_service_version: str = ""):
     """
     global service_version
     service_version = cus_service_version
-
+def get_service_version():
+    return custom_service_version if custom_service_version else service_version
 
 def set_socket_path(cus_collector_address: str = ""):
     """
@@ -352,6 +354,7 @@ def set_tenant_code_reader(str={}):
     # global tenant_code_reader
     for key in str:
         if key.get("ReaderType") and key.get("ReaderKey"):
+
             tenant_code_reader.append(key)
 
 
@@ -376,6 +379,7 @@ def set_service_version_reader(str={}):
     global service_version_reader
     for key in str:
         if key.get("ReaderType") and key.get("ReaderKey"):
+            functions.log("ReaderType:%s,ReaderKey:%s",key.get("ReaderType"),key.get("ReaderKey"))
             service_version_reader.append(key)
 
 
